@@ -299,6 +299,9 @@ _hd_launcher_update_orientation_cb (GQuark key_id,
 
   g_assert (HD_IS_LAUNCHER_PAGE (page));
 
+  /* Scrolling animation delays screen rotation. */
+  hd_launcher_page_stop_scrolling (page);
+
   grid = HD_LAUNCHER_GRID (hd_launcher_page_get_grid (page));
   /* actual layout update for the grid, reordering and resizing tiles */
   hd_launcher_grid_set_portrait (grid, portraited);
@@ -312,6 +315,9 @@ _hd_launcher_update_orientation_cb (GQuark key_id,
   else
     clutter_actor_set_size (scroller, HD_LAUNCHER_PAGE_WIDTH,
         HD_LAUNCHER_PAGE_HEIGHT);
+
+  /* Update the 'empty label' position. */
+  hd_launcher_page_update_emptylabel (page, portraited);
 }
 
 /* hd_launcher_update_orientation:
@@ -647,8 +653,14 @@ _hd_launcher_clear_page (GQuark key_id, gpointer data, gpointer user_data)
 static void
 _hd_launcher_layout_page (GQuark key_id, gpointer data, gpointer user_data)
 {
+  HdLauncherPrivate *priv = HD_LAUNCHER_GET_PRIVATE (hd_launcher_get ());
   HdLauncherPage *page = HD_LAUNCHER_PAGE (data);
-  hd_launcher_grid_layout(HD_LAUNCHER_GRID(hd_launcher_page_get_grid (page)));
+  HdLauncherGrid *grid = HD_LAUNCHER_GRID (hd_launcher_page_get_grid (page));
+
+  /* actual layout update for the grid, reordering and resizing tiles */
+  hd_launcher_grid_set_portrait (grid, priv->portraited);
+
+  hd_launcher_grid_layout (HD_LAUNCHER_GRID (grid));
 }
 
 static void
@@ -656,13 +668,15 @@ hd_launcher_populate_tree_starting (HdLauncherTree *tree, gpointer data)
 {
   HdLauncher *launcher = HD_LAUNCHER (data);
   HdLauncherPrivate *priv = HD_LAUNCHER_GET_PRIVATE (launcher);
+
   if (STATE_IS_LAUNCHER (hd_render_manager_get_state ()))
     {
-      if(priv->portraited)
-	      hd_render_manager_set_state (HDRM_STATE_HOME_PORTRAIT);
-			else
-				hd_render_manager_set_state (HDRM_STATE_HOME);
+      if (priv->portraited)
+        hd_render_manager_set_state (HDRM_STATE_HOME_PORTRAIT);
+      else
+        hd_render_manager_set_state (HDRM_STATE_HOME);
     }
+
   priv->active_page = NULL;
 
   if (priv->current_traversal)
@@ -841,10 +855,10 @@ hd_launcher_populate_tree_finished (HdLauncherTree *tree, gpointer data)
    * the screen until the user opens the power menu */
   if (STATE_IS_LAUNCHER (hd_render_manager_get_state ()))
     {
-      if(priv->portraited)
-	      hd_render_manager_set_state (HDRM_STATE_HOME_PORTRAIT);
-			else
-				hd_render_manager_set_state (HDRM_STATE_HOME);
+      if (priv->portraited)
+        hd_render_manager_set_state (HDRM_STATE_HOME_PORTRAIT);
+      else
+        hd_render_manager_set_state (HDRM_STATE_HOME);
     }
 
   /* First we traverse the list and create all the categories,
@@ -885,15 +899,17 @@ hd_launcher_transition_loading_timeout()
 	HdLauncherPrivate *priv = HD_LAUNCHER_GET_PRIVATE (hd_launcher_get ());
 
   hd_launcher_stop_loading_transition();
+  hd_render_manager_set_loading (NULL);
   /* Change state back to switcher (if other apps exist) or home if the app
    * starting failed */
   if (hd_task_navigator_has_apps())
     hd_render_manager_set_state(HDRM_STATE_TASK_NAV);
-  else {
-		if(priv->portraited)
+  else
+    {
+      if(priv->portraited)
 	    hd_render_manager_set_state (HDRM_STATE_HOME_PORTRAIT);
-		else
-			hd_render_manager_set_state (HDRM_STATE_HOME);
+      else
+        hd_render_manager_set_state (HDRM_STATE_HOME);
 	}
   return FALSE; // don't call again
 }
@@ -1098,16 +1114,16 @@ hd_launcher_transition_app_start (HdLauncherApp *item)
    * the timeline is called */
   hd_launcher_transition_new_frame(priv->launch_transition,
                                    0, launcher);
-  if (STATE_IS_APP(hd_render_manager_get_state()))
+  if (STATE_IS_APP (hd_render_manager_get_state ()))
     {
-      if (STATE_IS_PORTRAIT(hd_render_manager_get_state()))
+      if (STATE_IS_PORTRAIT (hd_render_manager_get_state ()))
         hd_render_manager_set_state (HDRM_STATE_LOADING_SUBWIN_PORTRAIT);
       else
         hd_render_manager_set_state (HDRM_STATE_LOADING_SUBWIN);
     }
   else
     {
-      if (STATE_IS_PORTRAIT(hd_render_manager_get_state()))
+      if (STATE_IS_PORTRAIT (hd_render_manager_get_state ()))
         hd_render_manager_set_state (HDRM_STATE_LOADING_PORTRAIT);
       else
         hd_render_manager_set_state (HDRM_STATE_LOADING);
@@ -1154,6 +1170,7 @@ hd_launcher_transition_is_playing(void)
 void hd_launcher_window_created(void)
 {
   hd_launcher_stop_loading_transition();
+  hd_render_manager_set_loading (NULL);
 }
 
 static void
@@ -1264,15 +1281,21 @@ hd_launcher_key_pressed (HdLauncher *self,
   return TRUE;
 }
 
-void 
-hd_launcher_activate(int p) {
-	HdLauncherPrivate *priv = HD_LAUNCHER_GET_PRIVATE (hd_launcher_get ());
-	if (hd_render_manager_get_state () != HDRM_STATE_LAUNCHER) return;
-	if(p==-1) {
-		hd_launcher_back_button_clicked();
-		return;
-	}
-	hd_launcher_page_activate(priv->active_page, p);
+void
+hd_launcher_activate (int p)
+{
+  HdLauncherPrivate *priv = HD_LAUNCHER_GET_PRIVATE (hd_launcher_get ());
+
+  if (hd_render_manager_get_state () != HDRM_STATE_LAUNCHER)
+    return;
+
+  if (p == -1)
+    {
+      hd_launcher_back_button_clicked();
+      return;
+    }
+
+  hd_launcher_page_activate(priv->active_page, p);
 }
 
 gboolean
@@ -1282,3 +1305,11 @@ hd_launcher_is_editor_in_landscape (void)
 
   return priv->is_editor_in_landscape;
 }
+
+gboolean
+hd_launcher_is_portrait (void)
+{
+  HdLauncherPrivate *priv = HD_LAUNCHER_GET_PRIVATE (hd_launcher_get ());
+
+  return priv->portraited;
+}
