@@ -52,6 +52,8 @@
 #include "launcher/hd-app-mgr.h"
 #include "home/hd-render-manager.h"
 #include "hd-transition.h"
+#include "hd-orientation-lock.h"
+#include "hd-home.h"
 
 #ifndef DISABLE_A11Y
 #include "hildon-desktop-a11y.h"
@@ -776,9 +778,21 @@ main (int argc, char **argv)
 
   hd_volume_profile_init ();
 
-  /* Move to landscape for safety. */
-  if (hd_util_change_screen_orientation (wm, FALSE));
-    hd_util_root_window_configured (wm);
+  /* Check if orientation is locked to portrait or the device is in vertical position. */
+  if (hd_orientation_lock_is_locked_to_portrait ()
+          || (!hd_orientation_lock_is_enabled () && hd_home_is_portrait_capable ()))
+    {
+      hd_render_manager_set_state (HDRM_STATE_HOME_PORTRAIT);
+      if (hd_util_change_screen_orientation (wm, TRUE));
+        hd_util_root_window_configured (wm);
+    }
+  else
+    {
+      /* Move to landscape for safety. */
+      if (hd_util_change_screen_orientation (wm, FALSE));
+        hd_util_root_window_configured (wm);
+    }
+
 
   /* NB: we call gtk_main as opposed to clutter_main or mb_wm_main_loop
    * because it does the most extra magic, such as supporting quit functions
